@@ -11,6 +11,51 @@ from flask_wtf import Form
 from flask_lwadmin import ConfigurationError
 
 
+# Default list object actions
+default_loa = [
+    {
+        'key': 'edit',
+        'label': 'Edit',
+        'icon': 'icon-edit',
+        'call': 'set_edit_button'
+    },
+    {
+        'key': 'delete',
+        'label': 'Delete',
+        'icon': 'icon-trash icon-white',
+        'confirm': True,
+        'confirm_message': 'Are you sure?',
+        'class': 'btn btn-small btn-danger',
+        'call': 'set_del_button'
+    }
+]
+
+# Default back action
+default_ba = [
+    {
+        'key': 'back',
+        'label': 'Back to list',
+        'url': None,
+        'class': 'btn btn-warning',
+        'icon': 'icon-backward'
+    }
+]
+
+# Default create/update submit actions
+default_sa = [
+    {
+        'key': 'save',
+        'label': 'Save',
+        'class': 'btn btn-primary'
+    },
+    {
+        'key': 'save_and_add',
+        'label': 'Save and Add',
+        'class': 'btn btn-primary'
+    }
+]
+
+
 class ConfigParser:
     NO_URL = 0
     URL_INTERNAL = 1
@@ -33,11 +78,16 @@ class ConfigParser:
             if 'display' in configuration['list'].keys():
                 self.parse_list_display(configuration['list']['display'])
 
+            if 'action' in configuration['list'].keys():
+                self.parse_list_action(configuration['list']['action'])
+
             if 'actions' in configuration['list'].keys():
                 self.parse_list_actions(configuration['list']['actions'])
 
             if 'object_actions' in configuration['list'].keys():
                 self.parse_list_object_actions(configuration['list']['object_actions'])
+            else:
+                self.parse_list_object_actions(default_loa)
 
             if 'batch' in configuration['list'].keys():
                 self.parse_batch(configuration['list']['batch'])
@@ -51,6 +101,15 @@ class ConfigParser:
                 raise ConfigurationError('Wrong configuration format for list display element')
             self.list_configuration['display'].append(element)
 
+    def parse_list_action(self, list_element):
+        if not all(k in list_element for k in ('url', )):
+            raise ConfigurationError('Wrong configuration format for list element')
+
+        if 'type' not in list_element.keys():
+            list_element['type'] = self.NO_URL
+
+        self.list_configuration['action'] = list_element
+
     def parse_list_actions(self, actions):
         for action in actions:
             parsed = self.parse_action(action)
@@ -91,17 +150,17 @@ class ConfigParser:
 
         return action
 
-    def parse_batch(self, batch_elemet):
-        if not all(k in batch_elemet for k in ('url', )):
+    def parse_batch(self, batch_element):
+        if not all(k in batch_element for k in ('url', )):
             raise ConfigurationError('Wrong configuration format for list filter element')
 
-        if 'type' not in batch_elemet.keys():
-            batch_elemet['type'] = self.NO_URL
+        if 'type' not in batch_element.keys():
+            batch_element['type'] = self.NO_URL
 
-        if 'form' not in batch_elemet.keys():
-            batch_elemet['form'] = None
+        if 'form' not in batch_element.keys():
+            batch_element['form'] = None
 
-        self.list_configuration['batch'] = batch_elemet
+        self.list_configuration['batch'] = batch_element
 
     def parse_filter(self, filter_element):
         if not all(k in filter_element for k in ('session_name', 'display', 'url')):
@@ -124,6 +183,13 @@ class ConfigParser:
     def get_list_display(self):
         return self.list_configuration.get('display', [])
 
+    def get_list_action(self):
+        action = self.list_configuration.get('action')
+        pre = action.copy()
+        if pre['type'] == self.URL_INTERNAL:
+            pre['url'] = url_for(pre['url'])
+        return pre
+
     def get_list_actions(self):
         actions = self.list_configuration.get('actions', [])
         for action in actions:
@@ -134,7 +200,7 @@ class ConfigParser:
             yield pre
 
     def is_list_object_actions(self):
-        return True if self.list_configuration.get('object_actions', []) else False
+        return True if len(self.list_configuration.get('object_actions', [])) > 0 else False
 
     def get_list_object_actions(self, call_object=None):
         actions = self.list_configuration.get('object_actions', [])
